@@ -7,7 +7,6 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KWindowConfig>
-#include <KWindowSystem>
 #include <QQuickWindow>
 #endif
 
@@ -21,15 +20,3 @@ void Controller::saveWindowGeometry(QQuickWindow *window)
     dataResource.sync();
 #endif
 }
-
-void Controller::raiseWindow(QQuickWindow *window)
-{
-#ifndef Q_OS_ANDROID
-    if (KWindowSystem::isPlatformWayland()) {
-        KWindowSystem::setCurrentXdgActivationToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"));
-        KWindowSystem::activateWindow(window->winId());
-    } else {
-        window->raise();
-    }
-#endif
-}
